FlagPolicy

Struct FlagPolicy 

pub struct FlagPolicy {
    pub flag_name: Option<String>,
    pub commands: Vec<String>,
    pub operation: Option<Operation>,
}
A policy for controlling the value of a flag.

Fields

flag_name: Option<String>

The name of the flag to enforce this policy on.

Note that this should be the full name of the flag, not the abbreviated name of the flag. If the user specifies the abbreviated name of a flag, that flag will be matched using its full name.

The “no” prefix will not be parsed, so for boolean flags, use the flag’s full name and explicitly set it to true or false.

commands: Vec<String>

If set, this flag policy is applied only if one of the given commands or a command that inherits from one of the given commands is being run. For instance, if “build” is one of the commands here, then this policy will apply to any command that inherits from build, such as info, coverage, or test. If empty, this flag policy is applied for all commands. This allows the policy setter to add all policies to the proto without having to determine which Bazel command the user is actually running. Additionally, Bazel allows multiple flags to be defined by the same name, and the specific flag definition is determined by the command.

operation: Option<Operation>

Implementations

Source

impl FlagPolicy

pub fn flag_name(&self) -> &str

Returns the value of flag_name, or the default value if flag_name is unset.