pub struct InvocationPolicy {
pub flag_policies: Vec<FlagPolicy>,
}Expand description
The –invocation_policy flag takes a base64-encoded binary-serialized or text formatted InvocationPolicy message.
Fields
flag_policies: Vec<FlagPolicy>Order matters. After expanding policies on expansion flags or flags with implicit requirements, only the final policy on a specific flag will be enforced onto the user’s command line.