pub struct PackageLoadMetrics {
pub name: Option<String>,
pub load_duration: Option<Duration>,
pub num_targets: Option<u64>,
pub computation_steps: Option<u64>,
pub num_transitive_loads: Option<u64>,
pub package_overhead: Option<u64>,
}Expand description
Message used to concisely report all package metrics.
Fields
name: Option<String>Name of the package.
load_duration: Option<Duration>Wall-time duration it took to construct the package.
num_targets: Option<u64>Number of targets created in the package.
computation_steps: Option<u64>Number of Starlark computation steps required to create the package.
num_transitive_loads: Option<u64>Number of transitive Starlark load()s required to create the package.
package_overhead: Option<u64>Numeric value given to the memory and general accounting costs associated with a loaded package. Values are an approximate but reasonable proxy for the real storage costs of a package.
Implementations
Sourceimpl PackageLoadMetrics
impl PackageLoadMetrics
Sourcepub fn num_targets(&self) -> u64
pub fn num_targets(&self) -> u64
Returns the value of num_targets, or the default value if num_targets is unset.
Sourcepub fn computation_steps(&self) -> u64
pub fn computation_steps(&self) -> u64
Returns the value of computation_steps, or the default value if computation_steps is unset.
Sourcepub fn num_transitive_loads(&self) -> u64
pub fn num_transitive_loads(&self) -> u64
Returns the value of num_transitive_loads, or the default value if num_transitive_loads is unset.
Sourcepub fn package_overhead(&self) -> u64
pub fn package_overhead(&self) -> u64
Returns the value of package_overhead, or the default value if package_overhead is unset.