pub struct BuildConfiguration {
pub code: i32,
}Expand description
Failure modes described by this category pertain to the Bazel invocation configuration consumed by Bazel’s analysis phase. This category is not intended as a grab-bag for all Bazel flag value constraint violations, which instead generally belong in the category for the subsystem whose flag values participate in the constraint.
Fields
code: i32Implementations