pub struct IncludeScanning {
pub code: i32,
pub package_loading_code: i32,
}Fields
code: i32package_loading_code: i32Implementations
Sourceimpl IncludeScanning
impl IncludeScanning
Sourcepub fn code(&self) -> Code
pub fn code(&self) -> Code
Returns the enum value of code, or the default if the field is set to an invalid enum value.
Sourcepub fn package_loading_code(&self) -> Code
pub fn package_loading_code(&self) -> Code
Returns the enum value of package_loading_code, or the default if the field is set to an invalid enum value.
Sourcepub fn set_package_loading_code(&mut self, value: Code)
pub fn set_package_loading_code(&mut self, value: Code)
Sets package_loading_code to the provided enum value.