pub struct Spawn {
pub code: i32,
pub catastrophic: bool,
pub spawn_exit_code: i32,
}Fields
code: i32catastrophic: boolFor Codes describing generic failure to spawn (eg. EXECUTION_FAILED and
EXECUTION_DENIED) the catastrophic field may be set to true indicating a
failure that immediately terminated the entire build tool.
spawn_exit_code: i32If Code is NON_ZERO_EXIT, the spawn_exit_code field may be set to the
non-zero exit code returned by the spawned process to the OS.
NOTE: This field must not be confused with the build tool’s overall exit code.
Implementations