pub struct BuildEvent {
pub event_time: Option<Timestamp>,
pub event: Option<Event>,
}Expand description
An event representing some state change that occurred in the build. This message does not include field for uniquely identifying an event.
Fields
event_time: Option<Timestamp>The timestamp of this event.
event: Option<Event>////////////////////////////////////////////////////////////////////////// Events that indicate a state change of a build request in the build queue.