pub struct OrderedBuildEvent {
pub stream_id: Option<StreamId>,
pub sequence_number: i64,
pub event: Option<BuildEvent>,
}Expand description
Build event with contextual information about the stream it belongs to and its position in that stream.
Fields
stream_id: Option<StreamId>Which build event stream this event belongs to.
sequence_number: i64The position of this event in the stream. The sequence numbers for a build event stream should be a sequence of consecutive natural numbers starting from one. (1, 2, 3, …)
event: Option<BuildEvent>The actual event.