pub struct PublishBuildEventServer<T: PublishBuildEvent> { /* private fields */ }server only.Expand description
A service for publishing BuildEvents. BuildEvents are generated by Build Systems to record actions taken during a Build. Events occur in streams, are identified by a StreamId, and ordered by sequence number in a stream.
A Build may contain several streams of BuildEvents, depending on the systems that are involved in the Build. Some BuildEvents are used to declare the beginning and end of major portions of a Build; these are called LifecycleEvents, and are used (for example) to indicate the beginning or end of a Build, and the beginning or end of an Invocation attempt (there can be more than 1 Invocation in a Build if, for example, a failure occurs somewhere and it needs to be retried).
Other, build-tool events represent actions taken by the Build tool, such as target objects produced via compilation, tests run, et cetera. There could be more than one build tool stream for an invocation attempt of a build.
Implementations
Sourceimpl<T: PublishBuildEvent> PublishBuildEventServer<T>
impl<T: PublishBuildEvent> PublishBuildEventServer<T>
pub fn new(inner: T) -> Self
pub fn from_arc(inner: Arc<T>) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> InterceptedService<Self, F>where
F: Interceptor,
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing requests with the given encoding.
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress responses with the given encoding, if the client supports it.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX