Modules
- build
- build_
event - Nested message and enum types in
BuildEvent. - build_
status - Nested message and enum types in
BuildStatus. - publish_
build_ event_ client - Generated client implementations.
- publish_
build_ event_ server - Generated server implementations.
- publish_
lifecycle_ event_ request - Nested message and enum types in
PublishLifecycleEventRequest. - stream_
id - Nested message and enum types in
StreamId. - v1
Structs
- Build
Event - An event representing some state change that occurred in the build. This message does not include field for uniquely identifying an event.
- Build
Status - Ordered
Build Event - Build event with contextual information about the stream it belongs to and its position in that stream.
- Publish
Build Tool Event Stream Request - Streaming request message for PublishBuildToolEventStream.
- Publish
Build Tool Event Stream Response - States which event has been committed. Any failure to commit will cause RPC errors, hence not recorded by this proto.
- Publish
Lifecycle Event Request - Publishes ‘lifecycle events’ that update the high-level state of a build:
- Stream
Id - Unique identifier for a build event stream.
Enums
- Console
Output Stream - The type of console output stream.